@@ -1,18 +1,11 @@
-from typing import (
-  Any,
-  Callable
-)
-from os import (
-  path,
-  remove,
-  rename
-)
+import os
+from typing import Any, Callable
 from ujson import loads
 from rapidjson import dumps
 class Database:
   def __init__(self, path: str = 'data.db'):
     self.path = path
-    if not path.exists(path): 
+    if not os.path.exists(path): 
       with open(path, 'x') as f: f.close()
   def put(self, data: Any) -> None:
     with open(self.path, 'a') as f: f.write(dumps(data, separators=(',', ':')) + '\n'); f.close()
@@ -34,4 +27,4 @@ class Database:
           else: o = True
         except: o = True
         if o: w.write(l)
-      r.close(); w.close(); remove(self.path); rename(self.path + '.bak', self.path)
\ No newline at end of file
+      r.close(); w.close(); os.remove(self.path); os.rename(self.path + '.bak', self.path)
\ No newline at end of file
